@@ -366,7 +366,7 @@ SlackConnectorOperatorType = Literal[
     "VALIDATE_NUMERIC",
 ]
 TaskTypeType = Literal[
-    "Arithmetic", "Filter", "Map", "Map_all", "Mask", "Merge", "Truncate", "Validate"
+    "Arithmetic", "Filter", "Map", "Map_all", "Mask", "Merge", "Passthrough", "Truncate", "Validate"
 ]
 TrendmicroConnectorOperatorType = Literal[
     "ADDITION",
@@ -578,6 +578,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
