@@ -147,6 +147,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "MarketoConnectorProfileCredentialsTypeDef",
     "MarketoConnectorProfilePropertiesTypeDef",
+    "MarketoDestinationPropertiesTypeDef",
     "MarketoSourcePropertiesTypeDef",
     "OAuth2CredentialsTypeDef",
     "OAuth2DefaultsTypeDef",
@@ -168,6 +169,7 @@ __all__ = (
     "S3SourcePropertiesTypeDef",
     "SAPODataConnectorProfileCredentialsTypeDef",
     "SAPODataConnectorProfilePropertiesTypeDef",
+    "SAPODataDestinationPropertiesTypeDef",
     "SAPODataSourcePropertiesTypeDef",
     "SalesforceConnectorProfileCredentialsTypeDef",
     "SalesforceConnectorProfilePropertiesTypeDef",
@@ -195,6 +197,7 @@ __all__ = (
     "StartFlowResponseTypeDef",
     "StopFlowRequestRequestTypeDef",
     "StopFlowResponseTypeDef",
+    "SuccessResponseHandlingConfigTypeDef",
     "SupportedFieldTypeDetailsTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TaskTypeDef",
@@ -1000,7 +1003,9 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
         "Honeycode": "HoneycodeDestinationPropertiesTypeDef",
         "CustomerProfiles": "CustomerProfilesDestinationPropertiesTypeDef",
         "Zendesk": "ZendeskDestinationPropertiesTypeDef",
+        "Marketo": "MarketoDestinationPropertiesTypeDef",
         "CustomConnector": "CustomConnectorDestinationPropertiesTypeDef",
+        "SAPOData": "SAPODataDestinationPropertiesTypeDef",
     },
     total=False,
 )
@@ -1403,6 +1408,27 @@ MarketoConnectorProfilePropertiesTypeDef = TypedDict(
     },
 )
 
+_RequiredMarketoDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredMarketoDestinationPropertiesTypeDef",
+    {
+        "object": str,
+    },
+)
+_OptionalMarketoDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalMarketoDestinationPropertiesTypeDef",
+    {
+        "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class MarketoDestinationPropertiesTypeDef(
+    _RequiredMarketoDestinationPropertiesTypeDef, _OptionalMarketoDestinationPropertiesTypeDef
+):
+    pass
+
+
 MarketoSourcePropertiesTypeDef = TypedDict(
     "MarketoSourcePropertiesTypeDef",
     {
@@ -1683,6 +1709,30 @@ class SAPODataConnectorProfilePropertiesTypeDef(
     pass
 
 
+_RequiredSAPODataDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredSAPODataDestinationPropertiesTypeDef",
+    {
+        "objectPath": str,
+    },
+)
+_OptionalSAPODataDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalSAPODataDestinationPropertiesTypeDef",
+    {
+        "successResponseHandlingConfig": "SuccessResponseHandlingConfigTypeDef",
+        "idFieldNames": Sequence[str],
+        "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
+        "writeOperationType": WriteOperationTypeType,
+    },
+    total=False,
+)
+
+
+class SAPODataDestinationPropertiesTypeDef(
+    _RequiredSAPODataDestinationPropertiesTypeDef, _OptionalSAPODataDestinationPropertiesTypeDef
+):
+    pass
+
+
 SAPODataSourcePropertiesTypeDef = TypedDict(
     "SAPODataSourcePropertiesTypeDef",
     {
@@ -2026,6 +2076,15 @@ StopFlowResponseTypeDef = TypedDict(
     },
 )
 
+SuccessResponseHandlingConfigTypeDef = TypedDict(
+    "SuccessResponseHandlingConfigTypeDef",
+    {
+        "bucketPrefix": str,
+        "bucketName": str,
+    },
+    total=False,
+)
+
 SupportedFieldTypeDetailsTypeDef = TypedDict(
     "SupportedFieldTypeDetailsTypeDef",
     {
